@@ -21,19 +21,34 @@
 
 #include "player.h"
 
-typedef enum {NOTPLAYING=0, PREGAME, INGAME, POSTGAME} Gamemode_gm;
-typedef enum {TAKETURNS=0, SIMULTANEOUS} Gametype_gm;
+typedef enum
+{ NOTPLAYING = 0, PREGAME, INGAME, POSTGAME }
+Gamemode_gm;
+
+typedef enum
+{ TAKETURNS = 0, SIMULTANEOUS }
+Gametype_gm;
+
+typedef enum
+{RANDOM=0, LOOSERFIRST, WINNERFIRST}
+Turnmodetype_gm;
+
+typedef enum
+{SU_ANGLE=0,SU_ARMOR,SU_WEAPON,SU_WIND,SU_PLAYER,SU_ALLPLSTATUS,SU_ALL}
+statusUpdate;
 
 extern Gamemode_gm gm_gamemode;
+extern Gametype_gm gm_gametype;
 extern char gm_quit;
 extern int gm_activeplayers;
 extern int gm_numberPlayers;
 extern int gm_currentRound;
 extern int gm_totalRounds;
+extern int gm_iAmServer;
 extern Player_pl *gm_firing_order[10];
 extern char gm_stuff_happening;
 extern int gm_death_queue[256];
 extern int gm_dq_pos;
-extern int gm_killNumber; /* how many people have died so far */
+extern int gm_killNumber;	/* how many people have died so far */
 extern int gm_def_armor;
 #endif
