@@ -29,4 +29,10 @@ extern char gm_activate_shots;
 extern int gm_shotgeneration;
 extern int gm_capital, gm_bounty, gm_stipend;
 
+void svProcessDeathQueue();
+void svSendWind(int *who);
+void svCommandLine();
+void svCommandParse(char *buf);
+void svCommandListPlayers();
+void svCommandHelp();
 #endif
