@@ -18,22 +18,31 @@
  */
 #include <stdio.h>
 #include <stdarg.h>
+#include <time.h>
 #include "log.h"
 
 /* simple logging facility.  gives us a nice central location
    control just how much we want to get spammed by KOTH */
 
-Levels_log log_level=INTERESTING;
+Levels_log log_level = INTERESTING;
 
-void logPrintf(Levels_log level, char* fmt, ...)
+inline void logPrintf(Levels_log level, char *fmt, ...)
 {
-    va_list ap;
-    char buf[4096];
+    if(log_level < level)
+	return;
+    else
+    {
+	va_list ap;
+	char buf[4096];
+	char hour[9];		/* eg. strlen("14:10:05") + 1 == 9 */
+	time_t t;
 
-	if(log_level < level) return;
-    
-    va_start(ap, fmt);
-    vsprintf(buf, fmt, ap);
-	fprintf(stderr, buf);
-    va_end(ap);
+
+	t = time(NULL);
+	strftime(hour, 9, "%H:%M:%S", localtime(&t));
+	va_start(ap, fmt);
+	vsprintf(buf, fmt, ap);
+	fprintf(stderr, "[%s] %s", hour, buf);
+	va_end(ap);
+    }
 }
