@@ -19,10 +19,12 @@
 #ifndef _LOG_H_
 #define _LOG_H_
 
-typedef enum {CRITICAL, INTERESTING, DEBUG, SPAM} Levels_log;
+typedef enum
+{ CRITICAL, INTERESTING, DEBUG, SPAM }
+Levels_log;
 
 extern Levels_log log_level;
 
-void logPrintf(Levels_log level, char* fmt, ...);
+inline void logPrintf(Levels_log level, char *fmt, ...);
 
 #endif
