@@ -20,15 +20,21 @@
 #ifndef _BASIC_H_
 #define _BASIC_H_
 
-Shellstat_bal wepBasicInit(struct Projectilepos_bal *prjpos, void** guide,
-						   Shellstat_bal (*initexplosion)(struct Projectilepos_bal *prjpos, 
-														  void** explosioninfo), 
-						   void** explosioninfo);
-Shellstat_bal wepBasicGuidance(void* info, struct Projectilepos_bal *prjpos, 
-							   Shellstat_bal (*initexplosion)(struct Projectilepos_bal *prjpos, 
-															  void** explosioninfo), 
-							   void **explosioninfo);
-Shellstat_bal wepBasicExplosionInit(struct Projectilepos_bal *prjpos, 
-									void** explosioninfo);
+Shellstat_bal wepBasicInit(struct Projectilepos_bal * prjpos, void **guide,
+			   Shellstat_bal(*initexplosion) (struct
+							  Projectilepos_bal
+							  * prjpos,
+							  void
+							  **explosioninfo),
+			   void **explosioninfo);
+Shellstat_bal wepBasicGuidance(void *info, struct Projectilepos_bal *prjpos,
+			       Shellstat_bal(*initexplosion) (struct
+							      Projectilepos_bal
+							      * prjpos,
+							      void
+							      **explosioninfo),
+			       void **explosioninfo);
+Shellstat_bal wepBasicExplosionInit(struct Projectilepos_bal *prjpos,
+				    void **explosioninfo);
 
 #endif
