@@ -20,7 +20,9 @@
 #ifndef _CLUSTER_H_
 #define _CLUSTER_H_
 
-Shellstat_bal wepClusterExplosionInit(struct Projectilepos_bal *prjpos, void** explosioninfo);
-Shellstat_bal wepFragmentExplosionInit(struct Projectilepos_bal *prjpos, void** explosioninfo);
+Shellstat_bal wepClusterExplosionInit(struct Projectilepos_bal * prjpos,
+				      void **explosioninfo);
+Shellstat_bal wepFragmentExplosionInit(struct Projectilepos_bal *prjpos,
+				       void **explosioninfo);
 
 #endif
