@@ -19,8 +19,10 @@
 
 #ifndef _DIRT_H_
 #define _DIRT_H_
+#include "../ballistics.h"
 
-Shellstat_bal wepDirtExplosionInit(struct Projectilepos_bal *prjpos, void** explosioninfo);
-Shellstat_bal wepDirtExplosion(void* info);
+Shellstat_bal wepDirtExplosionInit(struct Projectilepos_bal *prjpos,
+				   void **explosioninfo);
+Shellstat_bal wepDirtExplosion(void *info);
 
 #endif
