@@ -20,6 +20,7 @@
 #ifndef _LARGE_H_
 #define _LARGE_H_
 
-Shellstat_bal wepLargeExplosionInit(struct Projectilepos_bal *prjpos, void** explosioninfo);
+Shellstat_bal wepLargeExplosionInit(struct Projectilepos_bal * prjpos,
+				    void **explosioninfo);
 
 #endif
