@@ -20,8 +20,11 @@
 #ifndef _MIRV_H_
 #define _MIRV_H_
 
-Shellstat_bal wepMIRVGuidance(void* info, struct Projectilepos_bal *prjpos, 
-							   Shellstat_bal (*initexplosion)(struct Projectilepos_bal *prjpos, 
-															  void** explosioninfo), 
-							  void **explosioninfo);
+Shellstat_bal wepMIRVGuidance(void *info, struct Projectilepos_bal * prjpos,
+			      Shellstat_bal(*initexplosion) (struct
+							     Projectilepos_bal
+							     * prjpos,
+							     void
+							     **explosioninfo),
+			      void **explosioninfo);
 #endif
