@@ -21,26 +21,29 @@
 #include "../terrain.h"
 #include "simple.h"
 
-Shellstat_bal wepSimpleExplosion(void* info)
+Shellstat_bal wepSimpleExplosion(void *info)
 {
-    struct SimpleExplosion_wep *prj = (struct SimpleExplosion_wep *)info;
-	Player_pl *pcur;
-	
-    prj->r+=prj->dx;
+    struct SimpleExplosion_wep *prj = (struct SimpleExplosion_wep *) info;
+    Player_pl *pcur;
+
+    prj->r += prj->dx;
     if(prj->r > prj->max_radius)
     {
-		return FREEING;
+	return FREEING;
     }
-    else /* amazing how much the word "else" looks like the face of Yoda at 4:16 in the morning */
+    else			/* amazing how much the word "else" looks like the face of Yoda at 4:16 in the morning */
     {
-		terClearCircle(prj->x, prj->y, prj->r);
-		for(pcur=pl_begin; pcur; pcur=pcur->next) 
-		{
-			if(pcur->ready==READY && plPlayerInCircleArea(pcur, prj->x, prj->y, prj->r))
-			{
-				plDamageTank(pcur, EXPLOSIVE, prj->id, 1);
-			}
-		}
-		return EXPLODING;
-    }    
+	terClearCircle(prj->x, prj->y, prj->r);
+	for(pcur = pl_begin; pcur; pcur = pcur->next)
+	{
+	    if(pcur->ready == READY
+	       && plPlayerInCircleArea(pcur, prj->x, prj->y, prj->r))
+	    {
+		pcur->last_hit = prj->id;
+		plDamageTank(pcur, EXPLOSIVE,
+			     prj->id, prj->wid, 1);
+	    }
+	}
+	return EXPLODING;
+    }
 }
