@@ -20,7 +20,12 @@
 #ifndef _SIMPLEGFX_H_
 #define _SIMPLEGFX_H_
 
-void wgxDrawSimpleShot(struct Projectilepos_bal *prjpos, void* info);
-void wgxDrawSimpleExplosion(void* info);
-
+void wgxDrawSimpleShot(struct Projectilepos_bal *prjpos, void *info);
+void wgxDrawSimpleRedExplosion(void *info);
+void wgxDrawSimpleBlueExplosion(void *info);
+void wgxDrawSimpleGreenExplosion(void *info);
+void wgxDrawSimpleBlankExplosion(void *info);
+void wgxDrawSimpleOrangeExplosion(void *info);
+void wgxDrawSimpleCyanExplosion(void *info);
+void wgxDrawSimplePurpleExplosion(void *info);
 #endif
