@@ -22,17 +22,21 @@
 #include "../terrain.h"
 #include "tacnuke.h"
 
-Shellstat_bal wepTacNukeExplosionInit(struct Projectilepos_bal *prjpos, void** explosioninfo)
+Shellstat_bal
+wepTacNukeExplosionInit(struct Projectilepos_bal *prjpos, void **explosioninfo)
 {
-    struct SimpleExplosion_wep *e = (struct SimpleExplosion_wep*)malloc(sizeof(struct SimpleExplosion_wep));
+    struct SimpleExplosion_wep *e =
+	(struct SimpleExplosion_wep *)
+	malloc(sizeof(struct SimpleExplosion_wep));
 
-    e->x=prjpos->x;
-    e->y=prjpos->y;
-    e->r=0;
-    e->dx=9;
-	e->id=prjpos->id;
-    e->max_radius=200;
-    
-    *((struct SimpleExplosion_wep**)explosioninfo)=e;
+    e->x = prjpos->x;
+    e->y = prjpos->y;
+    e->r = 0;
+    e->dx = 9;
+    e->id = prjpos->id;
+    e->max_radius = 250;
+    e->wid = prjpos->wid;
+
+    *((struct SimpleExplosion_wep **) explosioninfo) = e;
     return EXPLODING;
 }
