@@ -22,6 +22,7 @@
 
 #include "../ballistics.h"
 
-Shellstat_bal wepTacNukeExplosionInit(struct Projectilepos_bal *prjpos, void** explosioninfo);
+Shellstat_bal wepTacNukeExplosionInit(struct Projectilepos_bal * prjpos,
+				      void **explosioninfo);
 
 #endif
